This folder is used to auto-generate the orchestrator configuration file based on the user's description and domain knowledge. The user can provide the description of the task that they want the AgentOrg to achieve and the domain knowledge that AgentOrg built upon. For example, the resources that orchestrator have access to, e.g website content, availble APIs, database, etc. Then the generator will generate the YAML configuration file for the user. The user can then modify the configuration file to fit their needs. The orchestrator will load the configuration file and reconstruct the graph to complete the task.